==> cybop-0.18.0.tar.gz: cybop-0.18.0/src/controller/unglobaliser/display_unglobaliser.c <==
/*
 * Copyright (C) 1999-2016. Christian Heller.
 *
 * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
 *
 * CYBOI is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * CYBOI is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with CYBOI. If not, see <http://www.gnu.org/licenses/>.
 *
 * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
 * CYBOP Developers <cybop-developers@nongnu.org>
 *
 * @version CYBOP 0.18.0 2016-12-21
 * @author Christian Heller <christian.heller@tuxtax.de>
 */

#ifndef DISPLAY_UNGLOBALISER_SOURCE
#define DISPLAY_UNGLOBALISER_SOURCE

#ifdef __APPLE__
    //?? Add cocoa support
#elif WIN32
    //?? Add win32 support
#elif GNU_LINUX_OPERATING_SYSTEM
    #include "../../controller/unglobaliser/x_window_system_unglobaliser.c"
#else
    #include "../../controller/unglobaliser/x_window_system_unglobaliser.c"
#endif

/**
 * Finalises display global variables.
 */
void unglobalise_display() {

#ifdef __APPLE__
    //?? Add cocoa support
#elif WIN32
    //?? Add win32 support
#elif GNU_LINUX_OPERATING_SYSTEM
    unglobalise_x_window_system();
#else
    unglobalise_x_window_system();
#endif
}

/* DISPLAY_UNGLOBALISER_SOURCE */
#endif

==> cybop-0.19.0.tar.gz: cybop-0.19.0/src/controller/unglobaliser/display_unglobaliser.c <==
/*
 * Copyright (C) 1999-2017. Christian Heller.
 *
 * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
 *
 * CYBOI is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * CYBOI is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with CYBOI. If not, see <http://www.gnu.org/licenses/>.
 *
 * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
 * CYBOP Developers <cybop-developers@nongnu.org>
 *
 * @version CYBOP 0.19.0 2017-04-10
 * @author Christian Heller <christian.heller@tuxtax.de>
 */

#ifndef DISPLAY_UNGLOBALISER_SOURCE
#define DISPLAY_UNGLOBALISER_SOURCE

#if defined(__linux__) || defined(__unix__)
    #include "../../controller/unglobaliser/x_window_system_unglobaliser.c"
#elif defined(__APPLE__) && defined(__MACH__)
    //?? Add cocoa support
// Use __CYGWIN__ too, if _WIN32 is not known to mingw.
#elif defined(_WIN32) || defined(__CYGWIN__)
    //?? Add win32 support
#else
    #error "Could not compile system. The operating system is not supported. Check out defined preprocessor macros!"
#endif

/**
 * Finalises display global variables.
 */
void unglobalise_display() {

#if defined(__linux__) || defined(__unix__)
    unglobalise_x_window_system();
#elif defined(__APPLE__) && defined(__MACH__)
    //?? Add cocoa support
// Use __CYGWIN__ too, if _WIN32 is not known to mingw.
#elif defined(_WIN32) || defined(__CYGWIN__)
    //?? Add win32 support
#else
    #error "Could not compile system. The operating system is not supported. Check out defined preprocessor macros!"
#endif
}

/* DISPLAY_UNGLOBALISER_SOURCE */
#endif
